---
title: <span class="badge builder"></span> DashboardDashboardTemplating
---
# <span class="badge builder"></span> DashboardDashboardTemplating

## Constructor

```python
DashboardDashboardTemplating()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.DashboardDashboardTemplating
```

### <span class="badge object-method"></span> list_val

List of configured template variables with their saved values along with some other metadata

```python
def list_val(list_val: list[cogbuilder.Builder[dashboard.VariableModel]]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [DashboardDashboardTemplating](./object-DashboardDashboardTemplating.md)
